@@ -4,6 +4,7 @@ import gzip
 import pandas as pd
 import requests
 import json
+import io
 
 
 class SpotifyCredential:
@@ -390,14 +391,13 @@ class SpotifyPrivate(SpotifyCredential):
         Returns:
             DataFrame com os dados da request
         """
-        # decompressed_response = gzip.decompress(request.content)
-        # my_json = decompressed_response.decode('utf-8')
+        decompressed_response = gzip.decompress(request.content)
+        my_json = decompressed_response.decode('utf-8')
         # my_json = f'[{my_json}]'
         # my_json = my_json.replace('\n', '')
         # my_json = my_json.replace('}{', '},{')
         # return json.loads(my_json)
-        data = request.json()
-        return pd.DataFrame(data)
+        return my_json
 
     def get_tracks(self) -> pd.DataFrame:
         """
